==> acapy_mydata_did_protocol-0.1.6-py3-none-any.whl: mydata_did/v1_0/routes/maps/tag_maps.py <==
from mydata_did.v1_0.message_types import SPEC_URI

TAGS_MYDATA_DID_OPERATIONS_LABEL = "Data Agreement - MyData DID Operations"
TAGS_MYDATA_DID_OPERATIONS = {
    "name": TAGS_MYDATA_DID_OPERATIONS_LABEL,
    "description": "MyData DID Protocol 1.0 (ADA RFC 0001)",
    "externalDocs": {
        "description": "Specification",
        "url": SPEC_URI,
    },
}

TAGS_DATA_AGREEMENT_CORE_FUNCTIONS_LABEL = "Data Agreement - Core Functions"
TAGS_DATA_AGREEMENT_CORE_FUNCTIONS = {
    "name": TAGS_DATA_AGREEMENT_CORE_FUNCTIONS_LABEL,
    "description": "Data Agreement Protocol 1.0 (ADA RFC 0002)",
    "externalDocs": {
        "description": "Specification",
        "url": SPEC_URI,
    },
}


TAGS_DATA_AGREEMENT_AUDITOR_FUNCTIONS_LABEL = "Data Agreement - Auditor Functions"
TAGS_DATA_AGREEMENT_AUDITOR_FUNCTIONS = {
    "name": TAGS_DATA_AGREEMENT_AUDITOR_FUNCTIONS_LABEL,
    "description": "Data Agreement Proofs Protocol 1.0 (ADA RFC 0004)",
    "externalDocs": {
        "description": "Specification",
        "url": SPEC_URI,
    },
}


TAGS_JSONLD_FUNCTIONS_LABEL = "JSON-LD"
TAGS_JSONLD_FUNCTIONS = {
    "name": TAGS_JSONLD_FUNCTIONS_LABEL,
    "description": "JSON-LD functions",
}


TAGS_DATA_CONTROLLER_FUNCTIONS_LABEL = "Data Controller"
TAGS_DATA_CONTROLLER_FUNCTIONS = {
    "name": TAGS_DATA_CONTROLLER_FUNCTIONS_LABEL,
    "description": "Data Controller functions",
}

TAGS_DATA_SUBJECT_FUNCTIONS_LABEL = "Data Subject"
TAGS_DATA_SUBJECT_FUNCTIONS = {
    "name": TAGS_DATA_SUBJECT_FUNCTIONS_LABEL,
    "description": "Data Subject functions",
}

==> acapy_mydata_did_protocol-0.1.10-py3-none-any.whl: mydata_did/v1_0/routes/maps/tag_maps.py <==
from mydata_did.v1_0.message_types import SPEC_URI

TAGS_MYDATA_DID_OPERATIONS_LABEL = "Data Agreement - MyData DID Operations"
TAGS_MYDATA_DID_OPERATIONS = {
    "name": TAGS_MYDATA_DID_OPERATIONS_LABEL,
    "description": "MyData DID Protocol (ADA RFC 0001)",
    "externalDocs": {
        "description": "Specification",
        "url": SPEC_URI,
    },
}

TAGS_DATA_AGREEMENT_CORE_FUNCTIONS_LABEL = "Data Agreement - Core Functions"
TAGS_DATA_AGREEMENT_CORE_FUNCTIONS = {
    "name": TAGS_DATA_AGREEMENT_CORE_FUNCTIONS_LABEL,
    "description": "Data Agreement Protocol (ADA RFC 0002)",
    "externalDocs": {
        "description": "Specification",
        "url": SPEC_URI,
    },
}


TAGS_DATA_AGREEMENT_AUDITOR_FUNCTIONS_LABEL = "Data Agreement - Auditor Functions"
TAGS_DATA_AGREEMENT_AUDITOR_FUNCTIONS = {
    "name": TAGS_DATA_AGREEMENT_AUDITOR_FUNCTIONS_LABEL,
    "description": "Data Agreement Proofs Protocol (ADA RFC 0004)",
    "externalDocs": {
        "description": "Specification",
        "url": SPEC_URI,
    },
}


TAGS_JSONLD_FUNCTIONS_LABEL = "JSON-LD"
TAGS_JSONLD_FUNCTIONS = {
    "name": TAGS_JSONLD_FUNCTIONS_LABEL,
    "description": "JSON-LD functions",
}


TAGS_DATA_CONTROLLER_FUNCTIONS_LABEL = "Data Controller"
TAGS_DATA_CONTROLLER_FUNCTIONS = {
    "name": TAGS_DATA_CONTROLLER_FUNCTIONS_LABEL,
    "description": "Data Controller functions",
}

TAGS_DATA_SUBJECT_FUNCTIONS_LABEL = "Data Subject"
TAGS_DATA_SUBJECT_FUNCTIONS = {
    "name": TAGS_DATA_SUBJECT_FUNCTIONS_LABEL,
    "description": "Data Subject functions",
}
